=== modified file 'libdrizzle/conn.c'
--- libdrizzle/conn.c	2011-02-24 05:46:00 +0000
+++ libdrizzle/conn.c	2011-03-04 19:43:39 +0000
@@ -485,6 +485,18 @@
                                              size_t total,
                                              drizzle_return_t *ret_ptr)
 {
+  drizzle_result_st *old_result;
+
+  for (old_result= con->result_list; old_result != NULL; old_result= old_result->next)
+  {
+    if (result == old_result)
+    {
+      drizzle_set_error(con->drizzle, "drizzle_command_write", "result struct already in use");
+      *ret_ptr= DRIZZLE_RETURN_INTERNAL_ERROR;
+      return result;    
+    }
+  }
+
   if (!(con->options & DRIZZLE_CON_READY))
   {
     if (con->options & DRIZZLE_CON_RAW_PACKET)

=== modified file 'plugin/slave/queue_consumer.cc'
--- plugin/slave/queue_consumer.cc	2011-03-01 20:07:54 +0000
+++ plugin/slave/queue_consumer.cc	2011-03-04 22:37:38 +0000
@@ -106,6 +106,11 @@
             si= sql.insert(si, '\\');
             ++si;
           }
+          else if (*si == ';')
+          {
+            si= sql.insert(si, '\\');
+            ++si;  /* advance back to the semicolon */
+          }
         }
       }
     }

=== modified file 'plugin/slave/queue_producer.cc'
--- plugin/slave/queue_producer.cc	2011-02-28 14:33:56 +0000
+++ plugin/slave/queue_producer.cc	2011-03-04 22:49:58 +0000
@@ -174,6 +174,7 @@
   if (drizzle_quit(&_connection, &result, &ret) == NULL)
   {
     _last_return= ret;
+    drizzle_result_free(&result);
     return false;
   }
 
@@ -235,7 +236,6 @@
 
   drizzle_return_t ret;
   drizzle_result_st result;
-  drizzle_result_create(&_connection, &result);
   drizzle_query_str(&_connection, &result, sql.c_str(), &ret);
   
   if (ret != DRIZZLE_RETURN_OK)
@@ -244,6 +244,7 @@
     _last_error_message= "Replication slave: ";
     _last_error_message.append(drizzle_error(&_drizzle));
     errmsg_printf(error::ERROR, _("%s"), _last_error_message.c_str());
+    drizzle_result_free(&result);
     return false;
   }
 
@@ -340,6 +341,11 @@
       it= message_text.insert(it, '\\');
       ++it;
     }
+    else if (*it == ';')
+    {
+      it= message_text.insert(it, '\\');
+      ++it;  /* advance back to the semicolon */
+    }
   }
 
   sql.append(message_text);
@@ -391,7 +397,6 @@
 
   drizzle_return_t ret;
   drizzle_result_st result;
-  drizzle_result_create(&_connection, &result);
   drizzle_query_str(&_connection, &result, sql.c_str(), &ret);
   
   if (ret != DRIZZLE_RETURN_OK)
@@ -400,6 +405,7 @@
     _last_error_message= "Replication slave: ";
     _last_error_message.append(drizzle_error(&_drizzle));
     errmsg_printf(error::ERROR, _("%s"), _last_error_message.c_str());
+    drizzle_result_free(&result);
     return false;
   }
 
@@ -425,6 +431,7 @@
     {
       errmsg_printf(error::ERROR,
                     _("Replication slave: Unable to insert into queue."));
+      drizzle_result_free(&result);
       return false;
     }
   }

=== modified file 'plugin/transaction_log/utilities/transaction_log_connection.cc'
--- plugin/transaction_log/utilities/transaction_log_connection.cc	2011-02-17 00:14:13 +0000
+++ plugin/transaction_log/utilities/transaction_log_connection.cc	2011-03-04 10:48:33 +0000
@@ -55,7 +55,6 @@
                                      drizzle_result_st *result)
 {
   drizzle_return_t ret;
-  drizzle_result_create(&connection, result);
   if (drizzle_query_str(&connection, result, str_query.c_str(), &ret) == NULL ||
       ret != DRIZZLE_RETURN_OK)
   {
@@ -69,6 +68,7 @@
     {
       cerr << "Error executing query: " <<
         drizzle_con_error(&connection) << endl;
+      drizzle_result_free(result);
     }
     return;
   }
@@ -77,6 +77,7 @@
   {
     cerr << "Could not buffer result: " <<
         drizzle_con_error(&connection) << endl;
+    drizzle_result_free(result);
     return;
   }
   return;

=== modified file 'plugin/transaction_log/utilities/transaction_reader.cc'
--- plugin/transaction_log/utilities/transaction_reader.cc	2011-02-17 00:14:13 +0000
+++ plugin/transaction_log/utilities/transaction_reader.cc	2011-03-04 10:48:33 +0000
@@ -612,6 +612,7 @@
                                         summarize, ignore_events,
                                         print_as_raw))
       {
+        drizzle_result_free(&result);
         return -1;
       }
     }

